@@ -149,7 +149,7 @@ annual_range.swmpr <- function(swmpr_in
     summarise(mean = mean(!! parm, na.rm = TRUE)
               , min = min(!! parm, na.rm = TRUE)
               , max = max(!! parm, na.rm = TRUE)
-              , .groups = "drop_last")
+              , .groups = "drop")
 
   dat_month <- dat_day %>%
     group_by(!! seas) %>%
@@ -158,7 +158,7 @@ annual_range.swmpr <- function(swmpr_in
               , max_avg = mean(!! maxi, na.rm = TRUE)
               , min = min(!! mini, na.rm = TRUE)
               , max = max(!! maxi, na.rm = TRUE)
-              , .groups = "drop_last")
+              , .groups = "drop")
 
   # ensure all factor levels are accounted for, even if there is no data
   dat_month <- tidyr::complete(dat_month, !! seas)
