@@ -161,7 +161,7 @@ historical_range.swmpr <- function(swmpr_in
     dplyr::summarise(mean = mean(!! parm, na.rm = TRUE)
                      , min = min(!! parm, na.rm = TRUE)
                      , max = max(!! parm, na.rm = TRUE)
-                     , .groups = "drop_last")
+                     , .groups = "drop")
 
   # Assign seasons
   dat_all$season <- assign_season(dat_all$date, ...)
@@ -179,7 +179,7 @@ historical_range.swmpr <- function(swmpr_in
     dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
                      , min = mean(!!  mini, na.rm = TRUE)
                      , max = mean(!! maxi, na.rm = TRUE)
-                     , .groups = "drop_last")
+                     , .groups = "drop")
 
   # Determine average min/max/mean for each month (for all years together)
   if(data_type != 'nut') {
@@ -188,7 +188,7 @@ historical_range.swmpr <- function(swmpr_in
       dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
                        , min = mean(!!  mini, na.rm = TRUE)
                        , max = mean(!! maxi, na.rm = TRUE)
-                       , .groups = "drop_last")
+                       , .groups = "drop")
 
     # Make some labels
     lab_hist_rng <- paste('Daily Avg Range \n(', rng[[1]], '-', rng[[2]], ')', sep = '')
@@ -202,7 +202,7 @@ historical_range.swmpr <- function(swmpr_in
       dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
                        , min = min(!!  mini, na.rm = TRUE)
                        , max = max(!! maxi, na.rm = TRUE)
-                       , .groups = "drop_last")
+                       , .groups = "drop")
 
     # Make some labels
     lab_hist_rng <- paste('Seasonal Range \n(', rng[[1]], '-', rng[[2]], ')', sep = '')
@@ -218,14 +218,14 @@ historical_range.swmpr <- function(swmpr_in
       dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
                        , min = mean(!!  mini, na.rm = TRUE)
                        , max = mean(!! maxi, na.rm = TRUE)
-                       , .groups = "drop_last")
+                       , .groups = "drop")
   } else {
     dat_yr <- dat_yr %>%
       dplyr::group_by(!! seas) %>%
       dplyr::summarise(mean = mean(!! avg, na.rm = TRUE)
                        , min = min(!!  mini, na.rm = TRUE)
                        , max = max(!! maxi, na.rm = TRUE)
-                       , .groups = "drop_last")
+                       , .groups = "drop")
   }
 
   # ensure all factor levels are accounted for, even if there is no data
